@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ReadLocker.h 2476 2007-07-01 05:37:50Z svn $
+ * $Id: ReadLocker.h 2483 2007-07-03 13:17:30Z svn $
  *****************************************************************************/
 
 #ifndef READ_LOCKER_H
@@ -69,6 +69,7 @@ public:
                                          get_wait_write(status));
                 if (apr_atomic_cas(lock_, new_status, status) == status) {
                     status_ = new_status;
+                    log_try_count("ReadLock", try_count);
                     return;
                 }
             } else if (((try_count & TIMEOUT_CHECK_MASK) == 0) &&
@@ -79,6 +80,7 @@ public:
                                          get_wait_write(status));
                 if (apr_atomic_cas(lock_, new_status, status) == status) {
                     status_ = new_status;
+                    log_try_count("ReadLock(TIME OUT)", try_count);
                     return;
                 }
             }
@@ -88,23 +90,28 @@ public:
     };
     ~ReadLocker()
     {
+        apr_size_t try_count;
         apr_uint32_t status;
 
+        try_count = 0;
         while (1) {
-            status = apr_atomic_read(lock_);
+            try_count++;
 
+            status = apr_atomic_read(lock_);
             if (get_age(status) != get_age(status_)) {
                 // 他のスレッドにてタイムアウト処理がされた
-                break;
+                log_try_count("ReadUnLock(TIME OUT)", try_count);
+                return;
             }
 
             if (apr_atomic_cas(lock_,
-                               make_status(get_age(status_),
-                                           get_read_count(status_) - 1,
+                               make_status(get_age(status),
+                                           get_read_count(status) - 1,
                                            PREFER_WRITE,
                                            get_wait_write(status)),
                                status) == status) {
-                break;
+                log_try_count("ReadUnLock", try_count);
+                return;
             }
         }
     };
