@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ReadWriteLocker.h 2477 2007-07-01 05:45:24Z svn $
+ * $Id: ReadWriteLocker.h 2483 2007-07-03 13:17:30Z svn $
  *****************************************************************************/
 
 #ifndef READ_WRITE_LOCKER_H
@@ -30,6 +30,10 @@
 
 #include "Environment.h"
 
+#ifdef DEBUG_LOCK
+#include <iostream>
+#endif
+
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -82,7 +86,7 @@ protected:
     {
 #if APR_HAS_THREADS
         // APR 0.x だと UNIX 環境の apr_thread_yield の中身は空なので
-#if (APR_MAJOR_VERSION == 0) && defined( _POSIX_PRIORITY_SCHEDULING)
+#if (APR_MAJOR_VERSION == 0) && defined(_POSIX_PRIORITY_SCHEDULING)
         sched_yield();
 #else
         apr_thread_yield();
@@ -142,6 +146,13 @@ protected:
             ((prefer_write & PREFER_WRITE_MASK) << PREFER_WRITE_SHIFT) |
             ((wait_write & WAIT_WRITE_MASK) << WAIT_WRITE_SHIFT);
     };
+    static void log_try_count(const char *label, apr_size_t try_count)
+    {
+#ifdef DEBUG_LOCK
+        std::cerr << "try_count[" << label << "] = " << try_count << std::endl;
+        std::cerr.flush();
+#endif
+    };
 
     /** 読み出し中のスレッドの数へのポインタ */
     apr_atomic_t *lock_;
