@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemManager.h 2454 2007-06-29 15:22:09Z svn $
+ * $Id: UploadItemManager.h 2472 2007-06-30 19:40:38Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_MANAGER_H
@@ -167,8 +167,8 @@ private:
     ThumbnailList *thumbnail_list_;
     /** 最終更新時刻 (in in 共有メモリ) */
     apr_time_t *mtime_;
-    /** マネージャへの参照の数 (in in 共有メモリ) */
-    apr_atomic_t *manager_ref_count_;
+    /** マネージャのロック (in in 共有メモリ) */
+    apr_atomic_t *lock_;
     /** 変更カウンタ (in in 共有メモリ) */
     apr_size_t *age_;
 };
