@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: WriteLocker.h 2473 2007-06-30 19:55:41Z svn $
+ * $Id: WriteLocker.h 2483 2007-07-03 13:17:30Z svn $
  *****************************************************************************/
 
 #ifndef WRITE_LOCKER_H
@@ -63,13 +63,12 @@ public:
         while (1) {
             try_count++;
 
-            MEMORY_BARRIER;
             status = apr_atomic_read(lock_);
-
             if (LIKELY(get_read_count(status) == NOT_LOCKED)) {
                 new_status = make_status(get_age(status), WRITE_LOCKED);
                 if (apr_atomic_cas(lock_, new_status, status) == status) {
                     status_ = new_status;
+                    log_try_count("WriteLock", try_count);
                     return;
                 }
             } else {
@@ -79,6 +78,7 @@ public:
                     new_status = make_status(get_age(status) + 1, WRITE_LOCKED);
                     if (apr_atomic_cas(lock_, new_status, status) == status) {
                         status_ = new_status;
+                        log_try_count("WriteLock(TIME OUT)", try_count);
                         return;
                     }
                 }
@@ -98,23 +98,27 @@ public:
     };
     ~WriteLocker()
     {
+        apr_size_t try_count;
         apr_uint32_t status;
 
+        try_count = 0;
         while (1) {
-            status = apr_atomic_read(lock_);
+            try_count++;
 
+            status = apr_atomic_read(lock_);
             if (get_age(status) != get_age(status_)) {
                 // 他のスレッドにてタイムアウト処理がされた
-                break;
+                log_try_count("WriteUnLock(TIME OUT)", try_count);
+                return;
             }
 
             if (apr_atomic_cas(lock_,
-                               make_status(get_age(status_), NOT_LOCKED,
+                               make_status(get_age(status), NOT_LOCKED,
                                            PREFER_NONE,
                                            get_wait_write(status)),
                                status) == status) {
-                status = apr_atomic_read(lock_);
-                break;
+                log_try_count("WriteUnLock", try_count);
+                return;
             }
         }
     };
