@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BasicFileWriter.cpp 2162 2006-12-03 14:36:10Z svn $
+ * $Id: BasicFileWriter.cpp 2388 2007-03-10 11:34:50Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -34,7 +34,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: BasicFileWriter.cpp 2162 2006-12-03 14:36:10Z svn $");
+SOURCE_INFO_ADD("$Id: BasicFileWriter.cpp 2388 2007-03-10 11:34:50Z svn $");
 #endif
 
 /******************************************************************************
@@ -126,7 +126,7 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
     from_file_path = argv[1];
     to_file_path = argv[2];
 
-    if (!is_exist(pool, from_file_path)) {
+    if (!File::is_exist(pool, from_file_path)) {
         THROW(MESSAGE_FILE_NOT_FOUND);
     }
 
