@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: DownloadFlowController.cpp 2381 2007-02-05 16:19:16Z svn $
+ * $Id: DownloadFlowController.cpp 2467 2007-06-30 02:57:59Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -35,7 +35,10 @@
 #include "WriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: DownloadFlowController.cpp 2381 2007-02-05 16:19:16Z svn $");
+SOURCE_INFO_ADD("$Id: DownloadFlowController.cpp 2467 2007-06-30 02:57:59Z svn $");
+
+const apr_size_t DownloadSession::DOWNLOAD_BUSY_SLEEP_SEC   = 5;
+
 
 /******************************************************************************
  * public メソッド
@@ -195,6 +198,19 @@ const char *DownloadFlowController::dump_downloader(apr_pool_t *pool,
 }
 
 
+bool DownloadSession::is_valid()
+{
+    if (!is_valid_) {
+        is_valid_ = flow_controller_->add_session(sockaddr_);
+
+        if (!is_valid_) {
+            apr_sleep(apr_time_from_sec(DOWNLOAD_BUSY_SLEEP_SEC));
+        }
+    }
+    return is_valid_;
+}
+
+
 /******************************************************************************
  * テスト
  *****************************************************************************/
