@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostProgressList.cpp 2381 2007-02-05 16:19:16Z svn $
+ * $Id: PostProgressList.cpp 2483 2007-07-03 13:17:30Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -34,7 +34,7 @@
 #include "WriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: PostProgressList.cpp 2381 2007-02-05 16:19:16Z svn $");
+SOURCE_INFO_ADD("$Id: PostProgressList.cpp 2483 2007-07-03 13:17:30Z svn $");
 
 using namespace std;
 
@@ -53,7 +53,7 @@ PostProgressList::PostProgressList()
 
 RequestReader::post_progress_t *PostProgressList::get(apr_uint32_t upload_id)
 {
-    ReadLocker lock(&lock_);
+//     ReadLocker lock(&lock_);
 
     if (upload_id == ID_DUMMY) {
         return progress_list_;
