@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: RFC1867Parser.cpp 2297 2006-12-24 03:13:15Z svn $
+ * $Id: RFC1867Parser.cpp 2388 2007-03-10 11:34:50Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -41,7 +41,7 @@
 using namespace std;
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: RFC1867Parser.cpp 2297 2006-12-24 03:13:15Z svn $");
+SOURCE_INFO_ADD("$Id: RFC1867Parser.cpp 2388 2007-03-10 11:34:50Z svn $");
 #endif
 
 #define AS_CONTENT(pointer)         reinterpret_cast<content_t *>(pointer)
@@ -313,7 +313,7 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
         dump_level = 0;
     }
 
-    if (!is_exist(pool, post_file_path)) {
+    if (!File::is_exist(pool, post_file_path)) {
         THROW(MESSAGE_FILE_NOT_FOUND);
     }
 
